##' Focused Information Criteria for Model Comparison
##'
##' For a full explanation of the methods behind the \pkg{fic} package and worked examples of using it, see the main package vignette "Different models for different purposes: focused model comparison in R"
##' 
##' @name fic-package
##' @aliases fic-package
##' 
##' @import stats
"_PACKAGE"
